package model

import (
	"time"
)

type O2oStore struct {
	Id                    int       `json:"id" xorm:"not null pk autoincr INT(11)"`
	Pid                   int       `json:"pid" xorm:"comment('用于以后连锁店使用') INT(11)"`
	StoreManager          int       `json:"store_manager" xorm:"comment('店长（商家id）') INT(11)"`
	ManagerRealname       string    `json:"manager_realname" xorm:"comment('店长真实名字') VARCHAR(255)"`
	ManagerPhone          string    `json:"manager_phone" xorm:"not null comment('店长手机号') VARCHAR(255)"`
	Business              float32   `json:"business" xorm:"comment('营业额') FLOAT(8,2)"`
	Name                  string    `json:"name" xorm:"comment('店铺名字') VARCHAR(255)"`
	Type                  int       `json:"type" xorm:"not null comment('店铺类型，类目id') INT(11)"`
	Sales                 string    `json:"sales" xorm:"not null default '0' comment('总销量') VARCHAR(255)"`
	ShopAvatarUrl         string    `json:"shop_avatar_url" xorm:"comment('店铺头像') VARCHAR(255)"`
	ShopBgimgUrl          string    `json:"shop_bgImg_url" xorm:"comment('店铺背景图') VARCHAR(255)"`
	State                 int       `json:"state" xorm:"not null default 1 comment('店铺状态:1未认证,2营业中,3,休息中,4关闭,5审核中,6认证失败') INT(255)"`
	Label                 string    `json:"label" xorm:"comment('店铺标签') VARCHAR(255)"`
	Remake                string    `json:"remake" xorm:"comment('店铺备注') VARCHAR(255)"`
	PayChannel            string    `json:"pay_channel" xorm:"comment('支持的付款方式，可多种') VARCHAR(255)"`
	StoreAddress          string    `json:"store_address" xorm:"comment('店铺地址') VARCHAR(255)"`
	StoreAddressDetails   string    `json:"store_address_details" xorm:"comment('店铺详情地址') VARCHAR(255)"`
	AuthInformation       string    `json:"auth_information" xorm:"comment('认证信息json') LONGTEXT"`
	IsHoliday             int       `json:"is_holiday" xorm:"comment('是否假日营业') TINYINT(1)"`
	BusinessDay           string    `json:"business_day" xorm:"not null comment('(1-6)表示周一到周六') VARCHAR(255)"`
	BusinessDayTitle      string    `json:"business_day_title" xorm:"not null comment('周一到周六') VARCHAR(255)"`
	BusinessStartTime     time.Time `json:"business_start_time" xorm:"comment('营业开始时间') DATETIME"`
	BusinessEndTime       time.Time `json:"business_end_time" xorm:"comment('营业结束时间') DATETIME"`
	IsEatIn               int       `json:"is_eat_in" xorm:"default 0 comment('是否支持堂食') TINYINT(1)"`
	IsDelivery            int       `json:"is_delivery" xorm:"default 0 comment('开启配送') TINYINT(1)"`
	IsAutoOrder           int       `json:"is_auto_order" xorm:"default 0 comment('是否自动接单') TINYINT(1)"`
	QrCodeImgUrl          string    `json:"qr_code_img_url" xorm:"comment('聚合二维码图片地址') VARCHAR(255)"`
	TransferRate          string    `json:"transfer_rate" xorm:"default '0' comment('转账费率') VARCHAR(255)"`
	Longitude             string    `json:"longitude" xorm:"not null default '' comment('经度') VARCHAR(255)"`
	Latitude              string    `json:"latitude" xorm:"not null default '' comment('纬度') VARCHAR(255)"`
	AccountAlipay         string    `json:"account_alipay" xorm:"default '' comment('支付宝账户号') VARCHAR(50)"`
	AccountAlipayRealName string    `json:"account_alipay_real_name" xorm:"default '' comment('支付宝持有人真实姓名') VARCHAR(255)"`
	JoinKey               string    `json:"join_key" xorm:"not null default '' comment('加盟口令') VARCHAR(255)"`
	StoreDiscount         string    `json:"store_discount" xorm:"not null default '9.8' comment('店铺折扣') VARCHAR(255)"`
	ValidTime             time.Time `json:"valid_time" xorm:"comment('有效时间') DATETIME"`
	CreateTime            time.Time `json:"create_time" xorm:"created not null default 'CURRENT_TIMESTAMP' comment('创建时间') DATETIME"`
	UpdateTime            time.Time `json:"update_time" xorm:"updated not null default 'CURRENT_TIMESTAMP' comment('更新时间') DATETIME"`
	DeletedTime           time.Time `json:"deleted_time" xorm:"comment('删除时间') DATETIME"`
	IsMealFee             int       `json:"is_meal_fee" xorm:"default 0 comment('是否开启餐位费(0:关闭1:开启)') TINYINT(3)"`
	MealFeeData           string    `json:"meal_fee_data" xorm:"comment('餐位费设置信息()') VARCHAR(255)"`
	FunctionData          string    `json:"function_data" xorm:"not null default '' comment('功能开关 json') VARCHAR(255)"`
	PayJumpType           int       `json:"pay_jump_type" xorm:"not null default 1 comment('支付跳转：1:小程序,  2:APP   默认：小程序') TINYINT(1)"`
	PayDiscount           string    `json:"pay_discount" xorm:"comment('收款码折扣') VARCHAR(255)"`
	PlaceOrdSet           int       `json:"place_ord_set" xorm:"not null default 1 comment('客户端商家下单按钮控制（0关1开）') TINYINT(1)"`
	StoreMainCategory     int       `json:"store_main_category" xorm:"comment('店铺主营类目（读店铺分类的is_main 1和2的）') INT(11)"`
	PayToMerchantType     int       `json:"pay_to_merchant_type" xorm:"not null default 0 comment('聚合二维码收款方式(付款给商家使用独立小程序/公域小程序) 0:公域 1:私域') TINYINT(1)"`
}
