package o2o

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/db/model"
	zhios_o2o_business_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_o2o_business.git/utils"
	"strconv"
	"time"
	"xorm.io/xorm"
)

//加入商家分佣 商家抽成部分
/***
commission 总佣金
bili	抽成 除以100之后的
uid	 用户id
oid 订单号
pvd 渠道
*/
func AddStoreCommission(eg *xorm.Engine, args map[string]string) {
	amount := zhios_o2o_business_utils.StrToFloat64(args["commission"]) * zhios_o2o_business_utils.StrToFloat64(args["bili"])
	if amount == 0 {
		return
	}
	user, err := db.UserProfileFindByID(eg, args["uid"])
	if err != nil || user == nil {
		return
	}
	if user.ParentUid == 0 {
		return
	}
	//判断是不是商家
	_, manager := GetO2oStore(eg, zhios_o2o_business_utils.IntToStr(user.ParentUid))
	if manager == nil {
		return
	}
	//判断有没有存过
	relate, _ := db.GetStoreCommissionRelate(eg, args["oid"], args["pvd"])
	if relate != nil {
		return
	}

	var ord = model.StoreCommissionRelate{
		Uid:        user.ParentUid,
		FormUid:    user.Uid,
		Pvd:        args["pvd"],
		Oid:        args["oid"],
		CreateTime: time.Now(),
		Amount:     zhios_o2o_business_utils.Float64ToStrByPrec(amount, 4),
		Rate:       args["bili"],
	}
	eg.InsertOne(&ord)
	return
}

//结算商家分佣 商家抽成部分
/***
oid 订单号
pvd 渠道
title 描述
*/
func SettleStoreCommission(eg *xorm.Engine, session *xorm.Session, args map[string]string) bool {
	relate, err := db.GetStoreCommissionRelateWithSession(session, args["oid"], args["pvd"])
	if err != nil {
		return false
	}
	if relate == nil {
		return true
	}
	if relate.SettleTime.IsZero() == false {
		return true
	}
	//判断是不是商家
	merchant, manager := GetO2oStore(eg, zhios_o2o_business_utils.IntToStr(relate.Uid))
	if manager == nil {
		return true
	}
	if manager.Id > 0 && zhios_o2o_business_utils.StrToFloat64(relate.Amount) > 0 {
		amount := zhios_o2o_business_utils.StrToFloat64(relate.Amount)
		mBeforeAmount := merchant.Amount
		mAfterAmount := mBeforeAmount + amount
		// o2o_fin_user_flow 新增流水记录
		var o2oFinUserFlow = model.O2oFinUserFlow{
			Uid:          relate.Uid,
			MerchantId:   relate.Uid,
			StoreId:      manager.Id,
			Type:         0,
			Amount:       strconv.FormatFloat(amount, 'f', 4, 64),
			BeforeAmount: strconv.FormatFloat(mBeforeAmount, 'f', 4, 64),
			AfterAmount:  strconv.FormatFloat(mAfterAmount, 'f', 4, 64),
			OrdType:      relate.Pvd,
			OrdId:        relate.Oid,
			OrdTitle:     args["title"],
			OrdAction:    11,
			OrdTime:      int(time.Now().Unix()),
			State:        2,
			CreateAt:     time.Now(),
			UpdateAt:     time.Now(),
		}
		merchant.Amount = mAfterAmount
		affected, err := db.MerchantUpdateWithSession(session, merchant, "amount")
		has, errs := session.Insert(&o2oFinUserFlow)
		if affected == 0 || err != nil || errs != nil || has == 0 {
			return false
		}
		relate.SettleTime = time.Now()
		update, err := session.Where("id=?", relate.Id).Cols("settle_time").Update(relate)
		if update == 0 || err != nil {
			return false
		}
	}
	return true
}

//扣除商家分佣 商家抽成部分
/***
oid 订单号
pvd 渠道
title 描述
*/
func DeductStoreCommission(eg *xorm.Engine, session *xorm.Session, args map[string]string) bool {
	relate, err := db.GetStoreCommissionRelateWithSession(session, args["oid"], args["pvd"])
	if err != nil {
		return false
	}
	if relate == nil {
		return true
	}
	if relate.SettleTime.IsZero() {
		return true
	}
	//判断是不是商家
	merchant, manager := GetO2oStore(eg, zhios_o2o_business_utils.IntToStr(relate.Uid))
	if manager == nil {
		return true
	}
	if manager.Id > 0 && zhios_o2o_business_utils.StrToFloat64(relate.Amount) > 0 {
		amount := zhios_o2o_business_utils.StrToFloat64(relate.Amount)
		mBeforeAmount := merchant.Amount
		mAfterAmount := mBeforeAmount - amount
		// o2o_fin_user_flow 新增流水记录
		var o2oFinUserFlow = model.O2oFinUserFlow{
			Uid:          relate.Uid,
			MerchantId:   relate.Uid,
			StoreId:      manager.Id,
			Type:         1,
			Amount:       strconv.FormatFloat(amount, 'f', 4, 64),
			BeforeAmount: strconv.FormatFloat(mBeforeAmount, 'f', 4, 64),
			AfterAmount:  strconv.FormatFloat(mAfterAmount, 'f', 4, 64),
			OrdType:      relate.Pvd,
			OrdId:        relate.Oid,
			OrdTitle:     args["title"],
			OrdAction:    11,
			OrdTime:      int(time.Now().Unix()),
			State:        2,
			CreateAt:     time.Now(),
			UpdateAt:     time.Now(),
		}
		merchant.Amount = mAfterAmount
		affected, err := db.MerchantUpdateWithSession(session, merchant, "amount")
		has, errs := session.Insert(&o2oFinUserFlow)
		if affected == 0 || err != nil || errs != nil || has == 0 {
			return false
		}
		relate.SettleTime = time.Time{}
		update, err := session.Where("id=?", relate.Id).Cols("settle_time").Update(relate)
		if update == 0 || err != nil {
			return false
		}
	}
	return true
}
